@@ -1,5 +1,5 @@
-{-# LANGUAGE ScopedTypeVariables #-}
-{-# OPTIONS -Wall -fno-warn-name-shadowing -fno-warn-missing-signatures -Werror #-}
+{-# LANGUAGE PackageImports, ScopedTypeVariables #-}
+{-# OPTIONS -Wwarn -Wall -fno-warn-name-shadowing -fno-warn-missing-signatures #-}
 -- |functions for killing processes, running processes, etc
 module System.Unix.Process
     (
@@ -33,7 +33,7 @@ module System.Unix.Process
 
 import Control.Concurrent (threadDelay)
 import Control.Monad (liftM, filterM)
-import Control.Monad.Trans (MonadIO(liftIO))
+import "mtl" Control.Monad.Trans (MonadIO(liftIO))
 --import Control.Exception hiding (catch)
 --import Control.Parallel.Strategies (rnf)
 import Data.Char (isDigit)
